@@ -8,9 +8,6 @@
  * 			Theodore Ts'o, tytso@mit.edu, 1/1/93
  *
  * Last modified: [tytso:19940520.0036EDT]
- *
- * added in support for the mc68000 kernel for debian
- *  Gordon Russell <g.russell@dcs.napier.ac.uk>
  */
 
 #include <stdio.h>
@@ -19,11 +16,12 @@
 #include <string.h>
 #include <errno.h>
 
-#include <linux/fs.h>
+#ifdef HAVE_ASM_IOCTLS_H
+#include <asm/ioctls.h>
+#endif
 #include <linux/serial.h>
-#include <linux/tty.h>
 
-#define VERSION_STR "2.12"
+#define VERSION_STR "2.14"
 
 char *progname;
 
@@ -46,16 +44,12 @@ struct serial_type_struct {
 #ifdef PORT_16650
 	PORT_16650,	"16650",
 #endif
-#ifdef __mc68000__
-         SER_SCC_NORM,   "SCC w/o DMA",
-         SER_SCC_DMA,    "SCC w/ DMA",
-         SER_MFP_CTRL,   "MFP",
-         SER_MFP_BARE,   "MFP w/o ctrl lines",
-         SER_MIDI,       "MIDI",
-         SER_AMIGA,      "Amiga builtin",
-         SER_IOEXT,      "GVP IO-Extender (16c552)",
-         SER_MFC_III,    "BSC MultiFaceCard III",
-#endif  /* __mc68000__ */
+#ifdef PORT_16650V2
+	PORT_16650V2, 	"16650V2",
+#endif
+#ifdef PORT_16750
+	PORT_16750,	"16750",
+#endif
 	PORT_UNKNOWN,	"none",
 	-1,		NULL
 };
@@ -381,8 +375,8 @@ void set_serial(char *device, char ** arg)
 	
 
 	if ((fd = open(device, O_RDWR|O_NONBLOCK)) < 0) {
-		if (verbosity==0 && (errno==ENOENT ||errno==ENODEV))
-			return;
+		if (verbosity==0 && errno==ENOENT)
+			exit(201);
 		perror(device);
 		exit(201);
 	}
@@ -549,7 +543,8 @@ void usage()
 	fprintf(stderr, "\t\t(^ = can be preceded by a '^' to turn off the option)\n");
 fprintf(stderr, "\t* port\t\tset the I/O port\n");
 	fprintf(stderr, "\t* irq\t\tset the interrupt\n");	
-	fprintf(stderr, "\t* uart\t\tset UART type (none, 8250, 16450, 16550, 16550A\n");
+	fprintf(stderr, "\t* uart\t\tset UART type (none, 8250, 16450, 16550, 16550A,\n");
+	fprintf(stderr, "\t\t\t16650, 16650V2, 16750)\n");
 	fprintf(stderr, "\t* baud_base\tset base baud rate (CLOCK_FREQ / 16)\n");
 	fprintf(stderr, "\t* divisor\tset the custom divisor (see spd_custom)\n");
 	fprintf(stderr, "\t* close_delay\tset the amount of time (in 1/100 of a\n");
